@@ -38,7 +38,7 @@ Q_EXPORT_PLUGIN2(XRandR11, XRandR11)
 XRandR11::XRandR11(QObject* parent)
  : QObject(parent)
  , m_valid(false)
- , m_x11Helper(new XRandRX11Helper())
+ , m_x11Helper(0)
  , m_currentConfig(0)
  , m_currentTimestamp(0)
 {
@@ -56,6 +56,8 @@ XRandR11::XRandR11(QObject* parent)
         return;
     }
 
+    m_x11Helper = new XRandRX11Helper();
+
     connect(m_x11Helper, SIGNAL(outputsChanged()), SLOT(updateConfig()));
 
     m_valid = true;
@@ -95,6 +97,7 @@ KScreen::Config* XRandR11::config() const
     screen->setCurrentSize(QSize(xcbScreen->width_in_pixels, xcbScreen->height_in_pixels));
     screen->setMaxSize(QSize(size->max_width, size->max_height));
     screen->setMinSize(QSize(size->min_width, size->min_height));
+    screen->setMaxActiveOutputsCount(1);
 
     config->setScreen(screen);
 
